==> fred-ferda-verification-1.0.0rc4.tar.gz: fred-ferda-verification-1.0.0rc4/assets/js/main.js <==
import 'vuetify/dist/vuetify.min.css'
import '@mdi/font/css/materialdesignicons.css'

import Notifications from '@remotehq/vue-notification'
import { get_i18next_options, get_vuetify_options, i18n, initialize_store } from 'FerdaJS/app.config'
import i18next from 'i18next'
import Backend from 'i18next-chained-backend'
import Vue from 'vue'
import VueCookies from 'vue-cookies'
import Vuetify from 'vuetify/lib'

import VerificationBaseView from './components/VerificationBaseView.vue'
import ContactVerification from './components/contact/ContactVerification.vue'
import DomainOwnerVerification from './components/domain/DomainOwnerVerification.vue'
import AccountCheck from './components/icons/AccountCheck.vue'
import AccountXmark from './components/icons/AccountXmark.vue'
import { get_ferda_verification_i18next_options, store } from './main.config'
import router from './router'

Vue.use(VueCookies)
Vue.use(Vuetify)
Vue.use(Notifications)

// Listen for store changes from Ferda and sync them with the store here
document.addEventListener('storechange', event => {
    const { payload, type } = event.detail

    if (store._actions[type]) {
        store.dispatch(type, payload.value)
        return
    }
    store.commit(type, payload.value)
})

const destination = document.currentScript.dataset.destination

document.addEventListener('DOMContentLoaded', async() => {
    const settings = document.querySelector('#ferda-verification-settings')?.textContent

    initialize_store(store)
    if (settings) {
        store.commit('verification_settings/set_verification_portal_url', JSON.parse(settings).verification_portal_url)
    }

    await i18next.use(Backend).init(get_i18next_options())
    await i18next.use(Backend).init(get_ferda_verification_i18next_options())

    const verificationEl = document.querySelector('#verification')

    const options = get_vuetify_options()
    options.theme.themes.dark = {
        ...options.theme.themes.dark,
        action_add: '#424242',
        action_approve: '#424242',
        action_resend: '#424242',
        action_delay: '#424242',
        action_manual_check: '#424242',
    }
    options.theme.themes.light = {
        ...options.theme.themes.dark,
        action_add: '#424242',
        action_approve: '#424242',
        action_resend: '#424242',
        action_delay: '#424242',
        action_manual_check: '#424242',
    }
    options.icons = {
        ...options.icons,
        values: {
            ...(options.icons && options.icons.values),
            account_check: {
                component: AccountCheck,
            },
            account_xmark: {
                component: AccountXmark,
            },
        },
    }

    if (verificationEl) {
        new Vue({
            el: '#verification',
            name: 'VerificationIndex',
            vuetify: new Vuetify(options),
            i18n,
            components: { VerificationBaseView },
            store,
            router,
            render: createElement => createElement(VerificationBaseView),
        })
    }

    if (destination === 'contact-detail') {
        const ferda_verification_section_el = document.createElement('div')
        ferda_verification_section_el.id = 'verification-section'

        document.querySelector('.v-main__wrap > div > div:nth-child(3) > div:nth-child(2) > div > div')
            .appendChild(ferda_verification_section_el)

        const contact_data = JSON.parse(document.querySelector('#contact-data').textContent)

        new Vue({
            el: '#verification-section',
            name: 'VerificationPlugin',
            vuetify: new Vuetify(options),
            i18n,
            components: { ContactVerification },
            store,
            render: createElement => createElement(ContactVerification, { props: { contact: contact_data }}),
        })
    }

    if (destination === 'domain-detail') {
        const original_title_el = document.querySelector(
            `.v-main__wrap > div > div:nth-child(3) > div:nth-child(2) > div >
            div > div:nth-child(2) > div > div > div > div > div > div`,
        )
        const original_title = original_title_el.innerText

        const new_title_el = document.createElement('div')
        new_title_el.id = 'verification-title-el'
        original_title_el.replaceWith(new_title_el)

        const registrant_id = JSON.parse(document.querySelector('#domain-data').textContent).object_info.registrant
        new Vue({
            el: '#verification-title-el',
            name: 'VerificationOwnerTitle',
            vuetify: new Vuetify(options),
            i18n,
            components: { DomainOwnerVerification },
            render: createElement => createElement(DomainOwnerVerification, {
                props: { registrant_id, original_title },
            }),
        })

    }
})

window.addEventListener('popstate', () => {
    location.reload()
})

==> fred-ferda-verification-1.1.0rc2.tar.gz: fred-ferda-verification-1.1.0rc2/assets/js/main.js <==
import 'vuetify/dist/vuetify.min.css'
import '@mdi/font/css/materialdesignicons.css'

import Notifications from '@remotehq/vue-notification'
import { get_i18next_options, get_vuetify_options, i18n, initialize_store } from 'FerdaJS/app.config'
import i18next from 'i18next'
import Backend from 'i18next-chained-backend'
import Vue from 'vue'
import VueCookies from 'vue-cookies'
import Vuetify from 'vuetify/lib'

import VerificationBaseView from './components/VerificationBaseView.vue'
import ContactVerification from './components/contact/ContactVerification.vue'
import DomainOwnerVerification from './components/domain/DomainOwnerVerification.vue'
import AccountCheck from './components/icons/AccountCheck.vue'
import AccountXmark from './components/icons/AccountXmark.vue'
import { get_ferda_verification_i18next_options, store } from './main.config'
import router from './router'

Vue.use(VueCookies)
Vue.use(Vuetify)
Vue.use(Notifications)

// Listen for store changes from Ferda and sync them with the store here
document.addEventListener('storechange', event => {
    const { payload, type } = event.detail

    if (store._actions[type]) {
        store.dispatch(type, payload.value)
        return
    }
    store.commit(type, payload.value)
})

const destination = document.currentScript.dataset.destination

document.addEventListener('DOMContentLoaded', async() => {
    const settings = document.querySelector('#ferda-verification-settings')?.textContent

    initialize_store(store)
    if (settings) {
        store.commit('verification_settings/set_verification_portal_url', JSON.parse(settings).verification_portal_url)
    }

    await i18next.use(Backend).init(get_i18next_options())
    await i18next.use(Backend).init(get_ferda_verification_i18next_options())

    const verificationEl = document.querySelector('#verification')

    const options = get_vuetify_options()
    options.theme.themes.dark = {
        ...options.theme.themes.dark,
        action_add: '#424242',
        action_approve: '#424242',
        action_resend: '#424242',
        action_delay: '#424242',
        action_manual_check: '#424242',
    }
    options.theme.themes.light = {
        ...options.theme.themes.dark,
        action_add: '#424242',
        action_approve: '#424242',
        action_resend: '#424242',
        action_delay: '#424242',
        action_manual_check: '#424242',
    }
    options.icons = {
        ...options.icons,
        values: {
            ...(options.icons && options.icons.values),
            account_check: {
                component: AccountCheck,
            },
            account_xmark: {
                component: AccountXmark,
            },
        },
    }
    const permissions = JSON.parse(document.querySelector('#user-permissions').textContent)

    if (verificationEl) {
        new Vue({
            el: '#verification',
            name: 'VerificationIndex',
            vuetify: new Vuetify(options),
            i18n,
            components: { VerificationBaseView },
            store,
            router,
            render: createElement => createElement(VerificationBaseView),
        })
    }

    if (destination === 'contact-detail' && permissions.includes('ferda_verification.can_view')) {
        const ferda_verification_section_el = document.createElement('div')
        ferda_verification_section_el.id = 'verification-section'

        document.querySelector('.v-main__wrap > div > div:nth-child(3) > div:nth-child(2) > div > div')
            .appendChild(ferda_verification_section_el)

        const contact_data = JSON.parse(document.querySelector('#contact-data').textContent)

        new Vue({
            el: '#verification-section',
            name: 'VerificationPlugin',
            vuetify: new Vuetify(options),
            i18n,
            components: { ContactVerification },
            store,
            render: createElement => createElement(ContactVerification, { props: { contact: contact_data }}),
        })
    }

    if (destination === 'domain-detail' && permissions.includes('ferda_verification.can_view')) {
        const original_title_el = document.querySelector(
            `.v-main__wrap > div > div:nth-child(3) > div:nth-child(2) > div >
            div > div:nth-child(2) > div > div > div > div > div > div`,
        )
        const original_title = original_title_el.innerText

        const new_title_el = document.createElement('div')
        new_title_el.id = 'verification-title-el'
        original_title_el.replaceWith(new_title_el)

        const registrant_id = JSON.parse(document.querySelector('#domain-data').textContent).object_info.registrant
        new Vue({
            el: '#verification-title-el',
            name: 'VerificationOwnerTitle',
            vuetify: new Vuetify(options),
            i18n,
            components: { DomainOwnerVerification },
            render: createElement => createElement(DomainOwnerVerification, {
                props: { registrant_id, original_title },
            }),
        })

    }
})

window.addEventListener('popstate', () => {
    location.reload()
})
